==> nucleo-amd-0.1.2.tgz: package/README.md <==
# AMD

Custom AMD implementation

[![Build Status](https://travis-ci.org/dobre-robert-marius/AMD.svg?branch=master)](https://travis-ci.org/dobre-robert-marius/AMD)
[![Bower version](https://badge.fury.io/bo/nucleo-amd.svg)](http://badge.fury.io/bo/nucleo-amd)
[![Code Climate](https://codeclimate.com/github/dobre-robert-marius/AMD/badges/gpa.svg)](https://codeclimate.com/github/dobre-robert-marius/AMD)
[![Dependency Status](https://david-dm.org/dobre-robert-marius/AMD.png)](https://david-dm.org/dobre-robert-marius/AMD)

[![Join the chat at https://gitter.im/dobre-robert-marius/AMD](https://badges.gitter.im/Join%20Chat.svg)](https://gitter.im/dobre-robert-marius/AMD?utm_source=badge&utm_medium=badge&utm_campaign=pr-badge&utm_content=badge)

### Usage

    // make documentation about:
    - define
    - require
    - accept relative paths

### Install

    npm install
    npm install -g grunt-cli

### Tests

    npm install -g testem
    npm install -g phantomjs

    grunt testing
    // testem is broken for the moment: cannot reload on file change
    testem

### Build

    grunt build:prod

### Deploy

    grunt deploy:patch
    grunt deploy:minor
    grunt deploy:major

## Authors ##

* [Robert Dobre](https://twitter.com/robert_cnih87)

## Versioning ##

This library follows [Semantic Versioning](http://semver.org)

## Want to help? ##

Please do! We are always looking to improve this framework. Please see our
[Contribution Guidelines](https://dobre-robert-marius/AMD/blob/master/CONTRIBUTING.md)
on how to properly submit issues and pull requests.

## MIT License ##
    The MIT License (MIT)

    Copyright (c) 2015 dobre robert marius

    Permission is hereby granted, free of charge, to any person obtaining a copy of
    this software and associated documentation files (the "Software"), to deal in
    the Software without restriction, including without limitation the rights to
    use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of
    the Software, and to permit persons to whom the Software is furnished to do so,
    subject to the following conditions:

    The above copyright notice and this permission notice shall be included in all
    copies or substantial portions of the Software.

    THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
    IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS
    FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR
    COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER
    IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
    CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

==> nucleo-amd-0.4.4.tgz: package/README.md <==
# AMD

Custom AMD implementation

[![Build Status](https://travis-ci.org/dobre-robert-marius/AMD.svg?branch=master)](https://travis-ci.org/dobre-robert-marius/AMD)
[![Bower version](https://badge.fury.io/bo/nucleo-amd.svg)](http://badge.fury.io/bo/nucleo-amd)
[![Code Climate](https://codeclimate.com/github/dobre-robert-marius/AMD/badges/gpa.svg)](https://codeclimate.com/github/dobre-robert-marius/AMD)
[![Dependency Status](https://david-dm.org/dobre-robert-marius/AMD.png)](https://david-dm.org/dobre-robert-marius/AMD)
[![devDependencies Status](https://david-dm.org/dobre-robert-marius/AMD/dev-status.svg)](https://david-dm.org/dobre-robert-marius/AMD?type=dev)

- [Usage](#usage)
- [Examples](docs/examples.md)
- [Install](#install)
- [Tests](#tests)
- [Build](#build)
- [Deploy](#deploy)

### Usage

[Example file](docs/usage.js)

### Install

    npm install
    npm install -g grunt-cli

### Tests

    npm install -g testem
    npm install -g phantomjs

    grunt testing
    // OR
    testem // but testem is broken for the moment: cannot reload on file change

### Build

    grunt build:prod // the output can be found in bin/nucleo-amd.browser.js

### Deploy

    grunt deploy          // alias for grunt deploy:patch
    grunt deploy:patch
    grunt deploy:minor
    grunt deploy:major

## Authors ##

* [Robert Dobre](https://twitter.com/robert_cnih87)

## Versioning ##

This library follows [Semantic Versioning](http://semver.org)

## Want to help? ##

Please do! We are always looking to improve this framework. Please see our
[Contribution Guidelines](https://dobre-robert-marius/AMD/blob/master/CONTRIBUTING.md)
on how to properly submit issues and pull requests.

![AMD](./contribute.png?raw=true)

## Communication ##

- If you **need help**, use [Stack Overflow](http://stackoverflow.com/questions/tagged/nucleo-amd). (Tag 'nucleo-amd')
- If you'd like to **ask a general question**, use [Stack Overflow](http://stackoverflow.com/questions/tagged/nucleo-amd).
- If you **found a bug**, open an issue.
- If you **have a feature request**, open an issue.
- If you **want to contribute**, submit a pull request.

## MIT License ##
    The MIT License (MIT)

    Copyright (c) 2015 dobre robert marius

    Permission is hereby granted, free of charge, to any person obtaining a copy of
    this software and associated documentation files (the "Software"), to deal in
    the Software without restriction, including without limitation the rights to
    use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of
    the Software, and to permit persons to whom the Software is furnished to do so,
    subject to the following conditions:

    The above copyright notice and this permission notice shall be included in all
    copies or substantial portions of the Software.

    THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
    IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS
    FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR
    COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER
    IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
    CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
